#ifndef BROJ_H
#define BROJ_H

// Uvedene biblioteke treba uvoziti po leksikografskom poretku
#include <iostream>
#include <string>
using namespace std;

class Broj {
// Klasa bi trebalo da postuje sledeci redosled navodjenja sekcija prava pristupa: public -> protected -> private
public:
	// Tip nabrajanja se koristi kad god neko polje moze da uzme vrednost iz nekog konacnog skupa vrednost.
	enum Tip { MOBILNI, FIKSNI };

	// Dobra praksa jeste da se parametri konstruktora nazovu isto kao i polja.
	Broj(const string& kod_drzave, const string& pozivni_broj, const string& broj_telefona, Tip fiksni);

	// U deklaraciji metoda ne mora da postoji ime parametara. Ime mora postojati u definiciji ako se koristi. U slucaju da ne postoji ime u deklaraciji, dobra praksa je da se ostavi komentar sta svaki parametar predstavlja
	// Objekte slozenih tipova (klasni tipovi, string, itd.) treba prosledjivati po referenci kako bi se izbegla bespotrebna i potencijalno vremenski zahtevna kopija objekata
	// Dodavanjem modifikatora 'const' uz parametar obezbedjujemo da se polja objekta prosledjenog kroz argumente metode nece menjati
	// Na taj nacin mozemo da prosledimo i konstantan i nekonstantan objekat metodi
	// Broj b1; const Broj b2; b2.istaDrzava(b1); b1.istaDrzava(b2);
	// -- Oba poziva metode se prevode, dok se drugi poziv metode 'istaDrzava' ne bi preveo da je parametar metode bio samo 'Broj&'
	bool istaDrzava(const Broj&) const;	// Modifikator 'const' u metodi oznacava da metoda obezbedjuje da se polja tekuceg objekta nece promeniti
	bool fiksni() const;				// Na taj nacin metoda moze da se pozove i za konstantne i za nekonstantne objekte
	void pisi() const;					// Broj b1; b1.pisi(); const Broj b2; b2.pisi();
										// -- Oba poziva metoda se prevode, dok se drugi poziv metode 'pisi' ne bi preveo da metoda 'pisi' nije bila oznacena kao 'const'

private:
	// Dobra praksa jeste da se nazivi svih polja nazivaju uz dodati sufiks '_' kako bi se razlikovala od istoimenih parametara
	Tip fiksni_;
	string kod_drzave_;
	string pozivni_broj_;
	string broj_telefona_;
};

#endif