#include "Usluge.h"

/*
 Usluga
*/

Usluga::Usluga(const Broj& broj_od, const Broj& broj_ka) : broj_od_(broj_od), broj_ka_(broj_ka) {}

void Usluga::pisi() const {
	broj_od_.pisi();
	cout << " -> ";
	broj_ka_.pisi();
}

/*
 Poziv
*/

																	// Bez inicijalizacije nasledjenog podobjekta, prevodilac inicijalizuje podobjekat podrazumevanim konstruktorom osnovne klase
																	// Kako klasa Usluga nema podrazumevani konstruktor, program se ne bi uspesno preveo
Poziv::Poziv(const Broj& broj_od, const Broj& broj_do, int trajanje) : Usluga(broj_od, broj_do), trajanje_(trajanje) {}

double Poziv::cena() const {
	if (trajanje_ == 0) return 0;
	if (broj_od_.istaDrzava(broj_ka_)) {
		return (uspostavljanjeVezeDom + (trajanje_ / 60 + 1) * zapocetiMinutDom);
	}
	else {
		return (uspostavljanjeVezeIno + (trajanje_ / 60 + 1) * zapocetiMinutIno);
	}
}

void Poziv::pisi() const {
	Usluga::pisi();
	cout << " (" << trajanje_ / 60 << ":" << trajanje_ % 60 << ")";
}

/*
 Poruka
*/

Poruka::Poruka(const Broj& broj_od, const Broj& broj_do, const string& tekst) : Usluga(broj_od, broj_do), tekst_(tekst) {
	// U slucaju da je jedan od brojeva fiksni, objekat Poruke ne treba da se kreira
	// U tom slucaju bacamo izuzetak
	// Izuzetak bacen u konstruktoru automatski unistava ceo objekat i sve delove koji su do tog trenutka inicijalizovani
	// U slucaju da smo do ovog trenutka napravili nesto u dinamickoj memoriji, morali bismo taj podatak da izbrisemo u try/catch naredbi i prosledimo izuzetak dalje
	/*
		try { 
			int* podatak = new int;
			if (broj_od_.fiksni() || broj_ka_.fiksni()) throw NeuspesnoPoslataPoruka("Poruku nije moguce poslati ukoliko je jedan od brojeva fiksni broj.");
		}
		catch(NeuspesnoPoslataPoruka& e) {
			delete podatak;	// brisanje podataka pre prosledjivanje izuzetka dalje i brisanja objekta
			throw;			// prosledjivanje izuzetka dalje -- ovo moramo da uradimo da bi objekat bio stvarno unisten
		}
	*/
	if (broj_od_.fiksni() || broj_ka_.fiksni()) throw NeuspesnoPoslataPoruka("Poruku nije moguce poslati ukoliko je jedan od brojeva fiksni broj.");
}

double Poruka::cena() const {
	if (broj_od_.istaDrzava(broj_ka_)) {
		return porukaDom;
	}
	else {
		return porukaIno;
	}
}

void Poruka::pisi() const {
	Usluga::pisi();
	cout << " " << tekst_;
}
